Repo

Struct Repo 

pub struct Repo { /* private fields */ }

Implementations

Source

impl Repo

pub const fn inner(&self) -> &Repository

pub fn local_path(&self) -> PathBuf

Returns the path to the local repo.

Panics

Should never happen

pub fn local_path_str(&self) -> String

Returns the path to the local repo as string.

Panics

Should never happen

pub fn sha(&self) -> Result<Option<String>, Error>

Returns the SHA of the currently checked-out commit, if any.

Errors

If some git-related magic goes south, or there is no commit.

pub fn branch(&self) -> Result<Option<String>, Error>

Returns the local name of the currently checked-out branch, if any.

Errors

If some git-related magic goes south, or the branch name is not valid UTF-8.

pub fn tag(&self) -> Result<Option<String>, Error>

Returns the name of the currently checked-out tag, if any tag points to the current HEAD.

Errors

If some git-related magic goes south, or the tag name is not valid UTF-8.

pub fn remote_tracking_branch(&self) -> Result<Option<String>, Error>

The local name of the remote tracking branch.

Errors

If some git-related magic goes south, or the remote name is not valid UTF-8.

pub fn remote_name(&self) -> Result<Option<String>, Error>

Local name of the main remote.

Errors

If some git-related magic goes south, or the reomte name is not valid UTF-8.

pub fn remote_clone_url(&self) -> Result<Option<String>, Error>

Returns the clone URL of the main remote, if there is any.

Errors

If some git-related magic goes south.

pub fn version(&self) -> Result<String, Error>

Returns the version of the current state of the repo. This is basically the result of “git describe –tags –all <and-some-more…>”.

Errors

If some git-related magic goes south.

pub fn commit_date(&self, date_format: &str) -> Result<String, Error>

Returns the commit-time (not author-time) of the last commit in the currently checked out history (=> HEAD)

Errors

If some git-related magic goes south.