pub struct Repo { /* private fields */ }Implementations
Sourceimpl Repo
impl Repo
pub const fn inner(&self) -> &Repository
Sourcepub fn local_path(&self) -> PathBuf
pub fn local_path(&self) -> PathBuf
Sourcepub fn local_path_str(&self) -> String
pub fn local_path_str(&self) -> String
Sourcepub fn sha(&self) -> Result<Option<String>, Error>
pub fn sha(&self) -> Result<Option<String>, Error>
Returns the SHA of the currently checked-out commit, if any.
Errors
If some git-related magic goes south, or there is no commit.
Sourcepub fn branch(&self) -> Result<Option<String>, Error>
pub fn branch(&self) -> Result<Option<String>, Error>
Returns the local name of the currently checked-out branch, if any.
Errors
If some git-related magic goes south, or the branch name is not valid UTF-8.
Sourcepub fn tag(&self) -> Result<Option<String>, Error>
pub fn tag(&self) -> Result<Option<String>, Error>
Returns the name of the currently checked-out tag, if any tag points to the current HEAD.
Errors
If some git-related magic goes south, or the tag name is not valid UTF-8.
Sourcepub fn remote_tracking_branch(&self) -> Result<Option<String>, Error>
pub fn remote_tracking_branch(&self) -> Result<Option<String>, Error>
The local name of the remote tracking branch.
Errors
If some git-related magic goes south, or the remote name is not valid UTF-8.
Sourcepub fn remote_name(&self) -> Result<Option<String>, Error>
pub fn remote_name(&self) -> Result<Option<String>, Error>
Local name of the main remote.
Errors
If some git-related magic goes south, or the reomte name is not valid UTF-8.
Sourcepub fn remote_clone_url(&self) -> Result<Option<String>, Error>
pub fn remote_clone_url(&self) -> Result<Option<String>, Error>
Returns the clone URL of the main remote, if there is any.
Errors
If some git-related magic goes south.